models/chat_profile_info library

Classes

ChatProfileInfo
Display profile used by chat titles, sender names, and avatars.

Typedefs

ChatProfileProvider = Future<ChatProfileInfo?> Function(BaseChannel channel, {Message? message})
Resolves display profile data for a user in a channel.