receivedMessageNotifier property
Emits newly received messages accepted by the current session.
Implementation
final ValueNotifier<Message?> receivedMessageNotifier =
ValueNotifier<Message?>(null);
Emits newly received messages accepted by the current session.
final ValueNotifier<Message?> receivedMessageNotifier =
ValueNotifier<Message?>(null);