hasMultipleEmojiPages property
bool
get
hasMultipleEmojiPages
Whether the emoji panel has more than one page.
Implementation
bool get hasMultipleEmojiPages => _emojiPages.length > 1;
Whether the emoji panel has more than one page.
bool get hasMultipleEmojiPages => _emojiPages.length > 1;