MessageInputLocationDraft class
Location payload selected from the MessageInput extension panel.
Constructors
- MessageInputLocationDraft({required double longitude, required double latitude, required String poiName, required String thumbnailPath})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- latitude → double
-
Location latitude.
final
- longitude → double
-
Location longitude.
final
- poiName → String
-
Display name for the selected place.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- thumbnailPath → String
-
Local thumbnail path for the location preview.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited