MessageInputMentionCandidate class

Candidate shown by MessageInput mention search.

Constructors

MessageInputMentionCandidate({required String userId, required String displayName})
const

Properties

displayName String
Name displayed in the input draft.
final
hashCode int
The hash code for this object.
no setterinherited
insertedText String
Text inserted into the input field.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userId String
Nexconn user id inserted into mentioned info.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited