MessageInputReferencePreviewConfig class

Configuration for the reference-message preview.

Constructors

MessageInputReferencePreviewConfig({Color? backgroundColor, EdgeInsets? padding, TextStyle? textStyle, Widget? closeIcon, MessageInputReferencePreviewBuilder? builder})
const

Properties

backgroundColor Color?
Preview background color.
final
builder MessageInputReferencePreviewBuilder?
Custom preview builder.
final
closeIcon Widget?
Close icon override.
final
hashCode int
The hash code for this object.
no setterinherited
padding EdgeInsets?
Preview content padding.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
textStyle TextStyle?
Text style for sender and summary.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited