MessageInputVoiceDraft class

Recorded voice payload ready to send.

Constructors

MessageInputVoiceDraft({required String path, required int duration, Duration? recordedDuration})
const

Properties

duration int
Duration in seconds passed to the voice message params.
final
hashCode int
The hash code for this object.
no setterinherited
path String
Local audio file path.
final
recordedDuration Duration?
Exact recorded duration when available.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited