MessageBubble class
Default renderer for a Nexconn Message bubble.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- MessageBubble
Constructors
-
MessageBubble({Key? key, BaseChannel? channel, required Message message, required ChatPageConfig config, bool selected = false, VoidCallback? onTap, VoidCallback? onDoubleTap, VoidCallback? onLongPress, GestureLongPressStartCallback? onLongPressStart, ValueChanged<
ChatMessageSwipeDirection> ? onSwipe, VoidCallback? onAvatarTap, VoidCallback? onAvatarLongPress, bool multiSelectMode = false, bool showTime = false, Map<MessageType, ChatMessageBubbleBuilder> ? customMessageBubbleBuilders}) -
const
Properties
- channel → BaseChannel?
-
final
- config → ChatPageConfig
-
final
-
customMessageBubbleBuilders
→ Map<
MessageType, ChatMessageBubbleBuilder> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- message → Message
-
final
- multiSelectMode → bool
-
final
- onAvatarLongPress → VoidCallback?
-
final
- onAvatarTap → VoidCallback?
-
final
- onDoubleTap → VoidCallback?
-
final
- onLongPress → VoidCallback?
-
final
- onLongPressStart → GestureLongPressStartCallback?
-
final
-
onSwipe
→ ValueChanged<
ChatMessageSwipeDirection> ? -
final
- onTap → VoidCallback?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selected → bool
-
final
- showTime → bool
-
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- combinePreviewKey → const Key
- failedStatusKey → const Key
- filePreviewContentKey → const Key
- mediaPreviewContentKey → const Key
- mediaPreviewKey → const Key
- referenceImagePreviewKey → const Key
- sendingStatusKey → const Key
- voiceDurationWidthKey → const Key