MessageInputMention class
Selected mention inserted into a message draft.
Constructors
- MessageInputMention({required String userId, required String displayName})
-
const
Properties
- displayName → String
-
Display name inserted into the text field.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- insertedText → String
-
Text inserted into the input draft.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- userId → String
-
Nexconn user id carried in message mentioned info.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited