MessageInputButtonConfig class
Configuration for a MessageInput toolbar button.
Constructors
- MessageInputButtonConfig({Widget? icon, Widget? activeIcon, double size = kInputFieldIconSize, EdgeInsets? padding, Color? color, Color? activeColor, bool visible = true})
-
const
Properties
- activeColor → Color?
-
Active icon color.
final
- activeIcon → Widget?
-
Icon shown when the control is active.
final
- color → Color?
-
Inactive icon color.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon → Widget?
-
Icon shown when the control is inactive.
final
- padding → EdgeInsets?
-
Padding around the button.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size → double
-
Icon size used by the default toolbar button.
final
- visible → bool
-
Whether this toolbar control is visible.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited