MessageInputEmojiPanelConfig class
Configuration for the emoji panel layout.
Constructors
- MessageInputEmojiPanelConfig({Color? backgroundColor, double height = 224.0, int rowCount = 3, int columnCount = 8, double emojiSize = 24.0, double rowSpacing = 10.0, double columnSpacing = 5.0, EdgeInsets padding = const EdgeInsets.all(15.0), MessageInputPanelIndicatorConfig pageIndicatorConfig = const MessageInputPanelIndicatorConfig(), Widget deleteIcon = const Icon(Icons.backspace, color: Color(0xFF666666), size: 24), MessageInputEmojiSendButtonConfig sendButtonConfig = const MessageInputEmojiSendButtonConfig(), MessageInputEmojiItemBuilder? emojiItemBuilder, MessageInputEmojiActionBuilder? deleteButtonBuilder, MessageInputEmojiActionBuilder? sendButtonBuilder})
-
const
Properties
- backgroundColor → Color?
-
final
- columnCount → int
-
final
- columnSpacing → double
-
final
- deleteButtonBuilder → MessageInputEmojiActionBuilder?
-
final
- deleteIcon → Widget
-
final
- emojiItemBuilder → MessageInputEmojiItemBuilder?
-
final
- emojiSize → double
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double
-
final
- padding → EdgeInsets
-
final
- pageIndicatorConfig → MessageInputPanelIndicatorConfig
-
final
- rowCount → int
-
final
- rowSpacing → double
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sendButtonBuilder → MessageInputEmojiActionBuilder?
-
final
- sendButtonConfig → MessageInputEmojiSendButtonConfig
-
final
Methods
-
copyWith(
{Color? backgroundColor, double? height, int? rowCount, int? columnCount, double? emojiSize, double? rowSpacing, double? columnSpacing, EdgeInsets? padding, MessageInputPanelIndicatorConfig? pageIndicatorConfig, Widget? deleteIcon, MessageInputEmojiSendButtonConfig? sendButtonConfig, MessageInputEmojiItemBuilder? emojiItemBuilder, MessageInputEmojiActionBuilder? deleteButtonBuilder, MessageInputEmojiActionBuilder? sendButtonBuilder}) → MessageInputEmojiPanelConfig -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited