MessageInputEmojiSendButtonConfig class
Configuration for the emoji panel send button.
Constructors
- MessageInputEmojiSendButtonConfig({String? text, double width = 60.0, double height = 35.0, Color? backgroundColor, TextStyle textStyle = const TextStyle(color: Colors.white, fontSize: 15, fontWeight: FontWeight.w500), double borderRadius = 8.0, EdgeInsets margin = const EdgeInsets.only(right: 15.0, bottom: 0.0)})
-
const
Properties
- backgroundColor → Color?
-
final
- borderRadius → double
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double
-
final
- margin → EdgeInsets
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- text → String?
-
final
- textStyle → TextStyle
-
final
- width → double
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited