MessageInputExtensionPanelConfig class
Configuration for the extension panel grid.
Constructors
- MessageInputExtensionPanelConfig({int itemsPerPage = 8, int crossAxisCount = 4, Color? backgroundColor, double mainAxisSpacing = 24.0, double crossAxisSpacing = 28.0, EdgeInsets padding = const EdgeInsets.fromLTRB(26, 16, 26, 42), MessageInputPanelIndicatorConfig pageIndicatorConfig = const MessageInputPanelIndicatorConfig(activeColor: Color(0xFF999999), inactiveColor: Color(0xFFD8D8D8)), double height = 224.0, double itemRadius = 6.0, double titleAreaHeight = 28.0})
-
const
Properties
- backgroundColor → Color?
-
final
- crossAxisCount → int
-
final
- crossAxisSpacing → double
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double
-
final
- itemRadius → double
-
final
- itemsPerPage → int
-
final
- mainAxisSpacing → double
-
final
- padding → EdgeInsets
-
final
- pageIndicatorConfig → MessageInputPanelIndicatorConfig
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- titleAreaHeight → double
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited