ChatUIImageUtil class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
getBase64NaturalSize(
String? value) → Size? -
getCachedBase64NaturalSize(
String? value) → Size? -
getCachedDecodedBase64(
String? value) → Uint8List? -
getDecodedBase64(
String? value) → Uint8List? -
getFileNaturalSize(
String? path) → Size? -
referenceThumbnailDisplaySize(
double width, double height, {double maxLength = referenceThumbnailDefaultMaxSize, double minLength = referenceThumbnailDefaultMinSize}) → Size -
referenceThumbnailDisplaySizeForRatio(
double ratio, {double maxLength = referenceThumbnailDefaultMaxSize, double minLength = referenceThumbnailDefaultMinSize}) → Size
Constants
- referenceThumbnailDefaultMaxSize → const double
- referenceThumbnailDefaultMinSize → const double